==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/DataTable/TableView.php <==
<?php
namespace Claromentis\Core\DataTable;

$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_7e84df6509b512ec6d3f" . "619df00b393a" => base64_decode("cmVjb3Jkc1RvdGF" . "s"), "_9785edd5ebc204f41" . "5762081467d2ef5" => base64_decode("ZH" . "Jh" . "dw" . "=="), "_b764559" . "6ad3b10c" . "f617a8a1" . "b58014d4" . "b" => base64_decode("dGFibGVfZXhwb3J0LmNz" . "dg=="), "_9a8a4d866593d6457" . "472ae60c5e4f771" => base64_decode("cmVjb3Jkc0Z" . "pbHRlcmVk"), "_ebff9d37a7bb577c57bee4" . "dd9f0e5fd7" => base64_decode("YXJyYXlfdmFsdWV" . "z"), "da" . "ta" => base64_decode("ZGF0YQ=" . "="));
use Claromentis\Core\Csv\Contract\FileExporter;
use Claromentis\Core\DataTable\Contract;
use Claromentis\Core\Http\FileStreamResponse;
use Claromentis\Core\Security\SecurityContext;






class TableView
{
    
    
    
    
    
    protected $source;
    
    
    
    
    
    protected $params;
    
    
    
    
    protected $filters;
    
    
    
    
    
    protected $exporter;
    
    
    
    
    protected $dt_draw;
    
    
    
    
    
    
    
    public function __construct(Contract\DataSource $_d0845bff5cd0ddb5ed1d7bd9db996f51, Contract\Parameters $_4c4d12d3e4f6cac68e3eecffe9887915, Contract\TableFilter $_e0bd284b1527841bc9c635873b56303b, FileExporter $_14d7763bd68d2a696994ae5aec7dad69 = null)
    {
        $this->source = $_d0845bff5cd0ddb5ed1d7bd9db996f51;
        $this->params = $_4c4d12d3e4f6cac68e3eecffe9887915;
        $this->filters = $_e0bd284b1527841bc9c635873b56303b;
        $this->exporter = $_14d7763bd68d2a696994ae5aec7dad69;
    }
    
    
    
    
    
    
    
    
    public function Draw(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_f4eafa5f493306ffdb51a688b21dd507 = $this->source->Count($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8);
        return array(
            $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["d" . "a" . "t" . "a"] => $_a0006f2e6058ce959e86bebdcded2da8,
            $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_7e84df6509b512e" . "c6d3f619df00b393" . "a"] => $_f4eafa5f493306ffdb51a688b21dd507,
            $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_9a8a4d8" . "66593d64" . "57472ae6" . "0c5e4f77" . "1"] => $_f4eafa5f493306ffdb51a688b21dd507,
            
            
            $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_9785edd5ebc204f415762081467d" . "2ef5"] => $this->dt_draw,
        );
    }
    
    
    
    
    
    
    
    
    public function Download(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8, true);
        $_3e258c4e6163007d8094c39647602e7a = array();
        foreach ($this->source->Columns($context, $this->params) as $_16e904583014a98ae3677f33f097518d) {
            $_3e258c4e6163007d8094c39647602e7a[] = $_16e904583014a98ae3677f33f097518d->GetName();
        }
        $data = array();
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $data[] = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_ebff9d37a7bb577c57b" . "ee4dd9f0e5fd7"]($_b8cfc2e06d9d1fec1893ea4a054002bf);
        }
        $this->exporter->SetHeaders($_3e258c4e6163007d8094c39647602e7a);
        $this->exporter->ImportFromArray($data);
        return $this->exporter->Export($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_b7645596ad3" . "b10cf617a8a1" . "b58014d4b"]);
    }
    
    
    
    
    
    
    
    
    
    
    protected function ConfigureRows(SecurityContext $context, $_a0006f2e6058ce959e86bebdcded2da8, $_34a970f5e5756ae52468c45ad07de116 = false)
    {
        $_e8180e518b009dc0ea8c578fe193c4ae = array();
        $_a42c86642011ef739b88ee80672c387d = $this->source->Columns($context, $this->params);
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $_b6e48cd3108f04ee53f45d7a66e14551 = array();
            foreach ($_b8cfc2e06d9d1fec1893ea4a054002bf as $_02ad4799244951c2d809ee37be9e79fd => $_16e904583014a98ae3677f33f097518d) {
                $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_16e904583014a98ae3677f33f097518d;
                if ($_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()) {
                    if ($_34a970f5e5756ae52468c45ad07de116) {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Basic($_16e904583014a98ae3677f33f097518d);
                    } else {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Decorate($_16e904583014a98ae3677f33f097518d);
                    }
                }
                $_b6e48cd3108f04ee53f45d7a66e14551[$_02ad4799244951c2d809ee37be9e79fd] = $_24ca62b4d01cc6d515dfd0bea4c9d59a;
            }
            $_e8180e518b009dc0ea8c578fe193c4ae[] = $_b6e48cd3108f04ee53f45d7a66e14551;
        }
        return $_e8180e518b009dc0ea8c578fe193c4ae;
    }
    
    
    
    
    
    
    public function SetDtDraw($_9785edd5ebc204f415762081467d2ef5)
    {
        $this->dt_draw = $_9785edd5ebc204f415762081467d2ef5;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/DataTable/TableView.php <==
<?php
namespace Claromentis\Core\DataTable;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_9a8a4d866593d6457472a" . "e60c5e4f771" => base64_decode("cmVjb3Jkc0" . "ZpbHRlcmVk"), "d" . "a" . "t" . "a" => base64_decode("ZGF0YQ" . "=="), "_7e84df6509b512ec6" . "d3f619df00b393a" => base64_decode("cmVjb3J" . "kc1RvdG" . "Fs"), "_b7645596ad3b10" . "cf617a8a1b58014" . "d4b" => base64_decode("dGFibGVfZXhwb3J0" . "LmNzdg=="), "_9785edd5" . "ebc204f41" . "576208146" . "7d2ef5" => base64_decode("ZHJ" . "hdw" . "=="), "_ebff9d37a7bb577" . "c57bee4dd9f0e5fd" . "7" => base64_decode("YXJyY" . "Xlfdm" . "FsdWV" . "z"));
use Claromentis\Core\Csv\Contract\FileExporter;
use Claromentis\Core\Http\FileStreamResponse;
use Claromentis\Core\Security\SecurityContext;






class TableView
{
    
    
    
    
    
    protected $source;
    
    
    
    
    
    protected $params;
    
    
    
    
    protected $filters;
    
    
    
    
    
    protected $exporter;
    
    
    
    
    protected $dt_draw;
    
    
    
    
    
    
    
    public function __construct(Contract\DataSource $_d0845bff5cd0ddb5ed1d7bd9db996f51, Contract\Parameters $_4c4d12d3e4f6cac68e3eecffe9887915, Contract\TableFilter $_e0bd284b1527841bc9c635873b56303b, FileExporter $_14d7763bd68d2a696994ae5aec7dad69 = null)
    {
        $this->source = $_d0845bff5cd0ddb5ed1d7bd9db996f51;
        $this->params = $_4c4d12d3e4f6cac68e3eecffe9887915;
        $this->filters = $_e0bd284b1527841bc9c635873b56303b;
        $this->exporter = $_14d7763bd68d2a696994ae5aec7dad69;
    }
    
    
    
    
    
    
    
    
    public function Draw(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_f4eafa5f493306ffdb51a688b21dd507 = $this->source->Count($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8);
        return array(
            $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["dat" . "a"] => $_a0006f2e6058ce959e86bebdcded2da8,
            $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_7e84df6509b512ec6d3f619df00" . "b393a"] => $_f4eafa5f493306ffdb51a688b21dd507,
            $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_9a8a4d866593d645747" . "2ae60c5e4f771"] => $_f4eafa5f493306ffdb51a688b21dd507,
            
            
            $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_9785edd5ebc20" . "4f415762081467" . "d2ef5"] => $this->dt_draw,
        );
    }
    
    
    
    
    
    
    
    
    public function Download(SecurityContext $context)
    {
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->source->Data($context, $this->params, $this->filters);
        $_a0006f2e6058ce959e86bebdcded2da8 = $this->ConfigureRows($context, $_a0006f2e6058ce959e86bebdcded2da8, true);
        $_3e258c4e6163007d8094c39647602e7a = array();
        foreach ($this->source->Columns($context, $this->params) as $_16e904583014a98ae3677f33f097518d) {
            $_3e258c4e6163007d8094c39647602e7a[] = $_16e904583014a98ae3677f33f097518d->GetName();
        }
        $data = array();
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $data[] = $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_ebff9d37a7bb577c57be" . "e4dd9f0e5fd7"]($_b8cfc2e06d9d1fec1893ea4a054002bf);
        }
        $this->exporter->SetHeaders($_3e258c4e6163007d8094c39647602e7a);
        $this->exporter->ImportFromArray($data);
        return $this->exporter->Export($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_b7645596ad3b10" . "cf617a8a1b58014" . "d4b"]);
    }
    
    
    
    
    
    
    
    
    
    
    protected function ConfigureRows(SecurityContext $context, $_a0006f2e6058ce959e86bebdcded2da8, $_34a970f5e5756ae52468c45ad07de116 = false)
    {
        $_e8180e518b009dc0ea8c578fe193c4ae = array();
        $_a42c86642011ef739b88ee80672c387d = $this->source->Columns($context, $this->params);
        foreach ($_a0006f2e6058ce959e86bebdcded2da8 as $_b8cfc2e06d9d1fec1893ea4a054002bf) {
            $_b6e48cd3108f04ee53f45d7a66e14551 = array();
            foreach ($_b8cfc2e06d9d1fec1893ea4a054002bf as $_02ad4799244951c2d809ee37be9e79fd => $_16e904583014a98ae3677f33f097518d) {
                $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_16e904583014a98ae3677f33f097518d;
                if ($_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()) {
                    if ($_34a970f5e5756ae52468c45ad07de116) {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Basic($_16e904583014a98ae3677f33f097518d);
                    } else {
                        $_24ca62b4d01cc6d515dfd0bea4c9d59a = $_a42c86642011ef739b88ee80672c387d[$_02ad4799244951c2d809ee37be9e79fd]->GetDecorator()->Decorate($_16e904583014a98ae3677f33f097518d);
                    }
                }
                $_b6e48cd3108f04ee53f45d7a66e14551[$_02ad4799244951c2d809ee37be9e79fd] = $_24ca62b4d01cc6d515dfd0bea4c9d59a;
            }
            $_e8180e518b009dc0ea8c578fe193c4ae[] = $_b6e48cd3108f04ee53f45d7a66e14551;
        }
        return $_e8180e518b009dc0ea8c578fe193c4ae;
    }
    
    
    
    
    
    
    public function SetDtDraw($_9785edd5ebc204f415762081467d2ef5)
    {
        $this->dt_draw = $_9785edd5ebc204f415762081467d2ef5;
    }
}
